@@ -1,5 +1,5 @@
 # pylint: disable=unused-import
-from highwire.events import Event, project
-from highwire.signals import Signal, LastEvent, Select
+from highwire.events import Event, project, Project
+from highwire.signals import Signal, LastEvent, Select, Crossover, Crossing
 from highwire.streams import Stream, AsyncStream
 from highwire.samplers import Sampler, MovingAverage, Tick
