@@ -1,6 +1,6 @@
 import asyncio
 import datetime as dt
-from typing import Any
+from typing import Any, List
 
 from highwire.events import Event
 from highwire.streams import AsyncStream
@@ -32,3 +32,19 @@ async def merge(t: AsyncStream[T], y: asyncio.Queue) -> AsyncStream[Any]:
 
     while True:
         yield await queue.get()
+
+
+async def window(t: AsyncStream[T], size: int) -> AsyncStream[List[T]]:
+    window = []
+    event = None
+    async for event in t:
+        window.append(event.value)  # type: ignore
+        if len(window) == size:
+            yield event.replace(window)  # type: ignore
+            event = None
+        if len(window) > size:
+            window.pop(0)
+            yield event.replace(window)  # type: ignore
+            event = None
+    if event is not None:
+        yield event.replace(window)
